@@ -273,11 +273,13 @@ class SPKExtractKeywordsInput(BaseModel):
         data: extended input text by InputKeyKeys, have the len as input.
         algorithms: which algorithms use for extract. Can be list of ["yake", "bert", "bert_vectorized", "tf_idf]
         keys: which keys need to extract
+        language: default is GERMAN
     """
 
     data: List[Dict[str, Dict[str, Any]]]
     algorithms: List[str] = ["yake", "bert"]
     keys: List[str] = []
+    language: SDULanguage = SDULanguage(code="de", lang="GERMAN")
 
 
 class SPKExtractKeywordsDTO(BaseModel):
